@@ -187,10 +187,12 @@ class LocalAutogradeExecutor(LoggingConfigurable):
         await self._run_subprocess(command, self.input_path)
         self.log.info("Successfully cloned repo")
 
-        command = f"{self.git_executable} checkout {self.submission.commit_hash}"
-        self.log.info(f"Running {command}")
-        await self._run_subprocess(command, self.input_path)
-        self.log.info(f"Now at commit {self.submission.commit_hash}")
+        # Checkout to commit of submission except when it was manually edited
+        if not self.submission.edited:
+            command = f"{self.git_executable} checkout {self.submission.commit_hash}"
+            self.log.info(f"Running {command}")
+            await self._run_subprocess(command, self.input_path)
+            self.log.info(f"Now at commit {self.submission.commit_hash}")
 
         self.submission.auto_status = "pending"
         self.session.commit()
@@ -228,7 +230,7 @@ class LocalAutogradeExecutor(LoggingConfigurable):
             return self.assignment.properties
 
         assignment_properties = json.loads(self.assignment.properties)
-        submission_properties = json.loads(self.submission.properties)
+        submission_properties = json.loads(self.submission.properties.properties)
         for notebook in assignment_properties["notebooks"].keys():
             if "notebooks" in submission_properties:
                 if notebook in submission_properties["notebooks"].keys():
