@@ -39,6 +39,13 @@ from grader_service.handlers.base_handler import GraderBaseHandler, authorize, R
 import datetime
 
 
+def remove_points_from_submission(submissions):
+    for s in submissions:
+        if not s.feedback_available:
+            s.score = None
+    return submissions
+
+
 @register_handler(
     path=r"\/lectures\/(?P<lecture_id>\d*)\/assignments\/(?P<assignment_id>\d*)\/submissions\/?",
     version_specifier=VersionSpecifier.ALL,
@@ -90,6 +97,7 @@ class SubmissionHandler(GraderBaseHandler):
 
                 # build the subquery
                 subquery = (self.session.query(Submission.username, func.max(Submission.date).label("max_date"))
+                            .filter(Submission.assignid == assignment_id)
                             .group_by(Submission.username)
                             .subquery())
 
@@ -97,13 +105,15 @@ class SubmissionHandler(GraderBaseHandler):
                 submissions = (
                     self.session.query(Submission)
                     .join(subquery,
-                          (Submission.username == subquery.c.username) & (Submission.date == subquery.c.max_date))
+                          (Submission.username == subquery.c.username) & (Submission.date == subquery.c.max_date) & (
+                                      Submission.assignid == assignment_id))
                     .all())
 
             elif submission_filter == 'best':
 
                 # build the subquery
                 subquery = (self.session.query(Submission.username, func.max(Submission.score).label("max_score"))
+                            .filter(Submission.assignid == assignment_id)
                             .group_by(Submission.username)
                             .subquery())
 
@@ -111,7 +121,8 @@ class SubmissionHandler(GraderBaseHandler):
                 submissions = (
                     self.session.query(Submission)
                     .join(subquery,
-                          (Submission.username == subquery.c.username) & (Submission.score == subquery.c.max_score))
+                          (Submission.username == subquery.c.username) & (Submission.score == subquery.c.max_score) & (
+                                      Submission.assignid == assignment_id))
                     .all())
 
             else:
@@ -120,6 +131,7 @@ class SubmissionHandler(GraderBaseHandler):
             if submission_filter == 'latest':
                 # build the subquery
                 subquery = (self.session.query(Submission.username, func.max(Submission.date).label("max_date"))
+                            .filter(Submission.assignid == assignment_id)
                             .group_by(Submission.username)
                             .subquery())
 
@@ -127,16 +139,18 @@ class SubmissionHandler(GraderBaseHandler):
                 submissions = (
                     self.session.query(Submission)
                     .join(subquery,
-                          (Submission.username == subquery.c.username) & (Submission.date == subquery.c.max_date))
+                          (Submission.username == subquery.c.username) & (Submission.date == subquery.c.max_date) & (
+                                      Submission.assignid == assignment_id))
                     .filter(
                         Submission.assignid == assignment_id,
-                        Submission.username == role.username,)
+                        Submission.username == role.username, )
                     .all())
 
             elif submission_filter == 'best':
 
                 # build the subquery
                 subquery = (self.session.query(Submission.username, func.max(Submission.score).label("max_score"))
+                            .filter(Submission.assignid == assignment_id)
                             .group_by(Submission.username)
                             .subquery())
 
@@ -144,7 +158,8 @@ class SubmissionHandler(GraderBaseHandler):
                 submissions = (
                     self.session.query(Submission)
                     .join(subquery,
-                          (Submission.username == subquery.c.username) & (Submission.score == subquery.c.max_score))
+                          (Submission.username == subquery.c.username) & (Submission.score == subquery.c.max_score) & (
+                                      Submission.assignid == assignment_id))
                     .filter(
                         Submission.assignid == assignment_id,
                         Submission.username == role.username, )
@@ -169,6 +184,9 @@ class SubmissionHandler(GraderBaseHandler):
                     self.write(",".join((k for k in d.keys() if k != "logs")) + "\n")
                 self.write(",".join((str(v) for k, v in d.items() if k != "logs")) + "\n")
         else:
+            if not instructor_version:
+                submissions = remove_points_from_submission(submissions)
+
             self.write_json(submissions)
         self.session.close()  # manually close here because on_finish overwrite
 
@@ -200,8 +218,11 @@ class SubmissionHandler(GraderBaseHandler):
         submission_ts = datetime.datetime.utcnow()
         if assignment.duedate is not None and submission_ts > assignment.duedate:
             raise HTTPError(HTTPStatus.CONFLICT, reason="Submission after due date of assignment!")
-        if assignment.max_submissions and len(assignment.submissions) >= assignment.max_submissions:
-            raise HTTPError(HTTPStatus.CONFLICT, reason="Maximum number of submissions reached!")
+        if assignment.max_submissions:
+            submissions = assignment.submissions
+            usersubmissions = [s for s in submissions if s.username == role.username]
+            if len(usersubmissions) >= assignment.max_submissions:
+                raise HTTPError(HTTPStatus.CONFLICT, reason="Maximum number of submissions reached!")
 
         submission = Submission()
         submission.assignid = assignment.id
@@ -371,7 +392,7 @@ class SubmissionPropertiesHandler(GraderBaseHandler):
         if properties is not None and properties.properties is not None:
             # delete source cells from properties if user is student
             if self.get_role(lecture_id).role == Scope.student:
-                model = GradeBookModel.from_dict(json.loads(properties))
+                model = GradeBookModel.from_dict(json.loads(properties.properties))
                 for notebook in model.notebooks.values():
                     notebook.source_cells_dict = {}
                 self.write(json.dumps(model.to_dict()))
@@ -434,13 +455,13 @@ class SubmissionEditHandler(GraderBaseHandler):
 
     @authorize([Scope.tutor, Scope.instructor])
     async def put(self, lecture_id: int, assignment_id: int, submission_id: int):
-        '''
+        """
         Create or overwrites the repository which stores changes of submissions files
         :param lecture_id: lecture id
         :param assignment_id: assignment id
         :param submission_id: submission id
         :return:
-        '''
+        """
         lecture_id, assignment_id = parse_ids(lecture_id, assignment_id)
         self.validate_parameters()
 
@@ -473,7 +494,7 @@ class SubmissionEditHandler(GraderBaseHandler):
         if not os.path.exists(git_repo_path):
             os.makedirs(git_repo_path, exist_ok=True)
 
-        self._run_command(f'git init --bare', git_repo_path)
+        await self._run_command_async(f'git init --bare', git_repo_path)
 
         # Create temporary paths to copy the submission files in the edit repository
         tmp_path = os.path.join(
@@ -502,16 +523,16 @@ class SubmissionEditHandler(GraderBaseHandler):
 
         # Init local repository
         command = f"git init"
-        self._run_command(command, tmp_input_path)
+        await self._run_command_async(command, tmp_input_path)
 
         # Pull user repository
         command = f'git pull "{submission_repo_path}" main'
-        self._run_command(command, tmp_input_path)
+        await self._run_command_async(command, tmp_input_path)
         self.log.info("Successfully cloned repo")
 
         # Checkout to correct submission commit
         command = f"git checkout {submission.commit_hash}"
-        self._run_command(command, tmp_input_path)
+        await self._run_command_async(command, tmp_input_path)
         self.log.info(f"Now at commit {submission.commit_hash}")
 
         # Copy files to output directory
@@ -519,31 +540,31 @@ class SubmissionEditHandler(GraderBaseHandler):
 
         # Init local repository
         command = f"git init"
-        self._run_command(command, tmp_output_path)
+        await self._run_command_async(command, tmp_output_path)
 
         # Add edit remote
         command = f"git remote add edit {git_repo_path}"
-        self._run_command(command, tmp_output_path)
+        await self._run_command_async(command, tmp_output_path)
         self.log.info("Successfully added edit remote")
 
         # Switch to main
         command = f"git switch -c main"
-        self._run_command(command, tmp_output_path)
+        await self._run_command_async(command, tmp_output_path)
         self.log.info("Successfully switched to branch main")
 
         # Add files to staging
         command = f"git add -A"
-        self._run_command(command, tmp_output_path)
+        await self._run_command_async(command, tmp_output_path)
         self.log.info("Successfully added files to staging")
 
         # Commit Files
         command = f'git commit -m "Initial commit" '
-        self._run_command(command, tmp_output_path)
+        await self._run_command_async(command, tmp_output_path)
         self.log.info("Successfully commited files")
 
         # Push copied files
         command = f"git push edit main"
-        self._run_command(command, tmp_output_path)
+        await self._run_command_async(command, tmp_output_path)
         self.log.info("Successfully pushed copied files")
 
         submission.edited = True
@@ -560,18 +581,19 @@ class LtiSyncHandler(GraderBaseHandler):
 
     @authorize([Scope.instructor])
     async def get(self, lecture_id: int, assignment_id: int):
+        # build the subquery
+        subquery = (self.session.query(Submission.username, func.max(Submission.date).label("max_date"))
+                    .filter(Submission.assignid == assignment_id, Submission.feedback_available)
+                    .group_by(Submission.username)
+                    .subquery())
+
+        # build the main query
         submissions = (
-            self.session.query(
-                Submission.id,
-                Submission.username,
-                Submission.score,
-                func.max(Submission.date)
-            )
-            .filter(Submission.assignid == assignment_id, Submission.auto_status == "automatically_graded",
-                    Submission.feedback_available == True)
-            .group_by(Submission.username)
-            .all()
-        )
+            self.session.query(Submission)
+            .join(subquery,
+                  (Submission.username == subquery.c.username) & (Submission.date == subquery.c.max_date) & (
+                          Submission.assignid == assignment_id) & Submission.feedback_available)
+            .all())
 
         assignment = self.get_assignment(lecture_id, assignment_id)
 
@@ -582,7 +604,7 @@ class LtiSyncHandler(GraderBaseHandler):
                             reason="Unable to match users: lti_username_convert is not set in grader "
                                    "config")
 
-        scores = [{"id": s[0], "username": lti_username_convert(s[1]), "score": s[2]} for s in submissions]
+        scores = [{"id": s.id, "username": lti_username_convert(s.username), "score": s.score} for s in submissions]
         stamp = datetime.datetime.now()
         if LtiSyncHandler.cache_token["token"] and LtiSyncHandler.cache_token["ttl"] > stamp - datetime.timedelta(
                 minutes=50):
