@@ -12,6 +12,7 @@ from sqlalchemy import (
     DateTime,
     Enum,
     ForeignKey,
+    Float,
     Integer,
     String,
     Text,
@@ -31,19 +32,21 @@ class Submission(Base, Serializable):
         nullable=False,
     )
     manual_status = Column(Enum("not_graded", "manually_graded","being_edited"))
-    score = Column(Integer, nullable=True)
+    score = Column(Float, nullable=True)
     assignid = Column(Integer, ForeignKey("assignment.id"))
     username = Column(String(255), ForeignKey("user.name"))
     commit_hash = Column(String(length=40), nullable=False)
-    properties = Column(Text, nullable=True, unique=False)
     feedback_available = Column(Boolean, nullable=False)
     edited = Column(Boolean, nullable=False)
-    logs = Column(Text, nullable=True)
     updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow, nullable=False)
 
     assignment = relationship("Assignment", back_populates="submissions")
     user = relationship("User", back_populates="submissions")
 
+    logs = relationship("SubmissionLogs", back_populates="submission", uselist=False)
+    properties = relationship("SubmissionProperties", back_populates="submission", uselist=False)
+
+
     @property
     def model(self) -> submission.Submission:
         return submission.Submission(
@@ -57,6 +60,5 @@ class Submission(Base, Serializable):
             score=self.score,
             commit_hash=self.commit_hash,
             feedback_available=self.feedback_available,
-            edited=self.edited,
-            logs=self.logs
+            edited=self.edited
         )
